# API Reference

## OME-NGFF (OME-Zarr)

- [OME-NGFF](ngff.md) - Core OME-Zarr reading and writing

## Readers

- [Readers](readers.md) - TIFF-based format readers (Micro-Manager, NDTiff, ClearControl, PTI)

## Conversion

- [Converter](converter.md) - TIFF to OME-Zarr conversion
